package
Version:
v0.0.0-...-231ddfd
Opens a new window with list of versions in this module.
Published: Aug 2, 2022
License: AGPL-3.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type AboutResponse struct {
Version string `json:"version"`
LastReloaded time.Time `json:"last_reloaded"`
Started time.Time `json:"started"`
}
type UpdateConfigurationRequest struct {
WorkerPoolCount *uint `json:"worker_pool_count" echotools:"required"`
ProcessTimeout *uint `json:"process_timeout" echotools:"required"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.